@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: project-template
 version: 0.2.0
-id: project-template-0.2.0-eb064117f46a16a8ac5b0c44c14f0dab
-key: proje_0rTUlVHdAwN2uMITurt567
+id: project-template-0.2.0-0ebb1cce2ec2d08df15ffddfdf2f6c6b
+key: proje_6fptC5TJhHPGycOZmBa8sO
 license: BSD3
 maintainer: michael@fpcomplete.com
 homepage: https://github.com/fpco/haskell-ide
@@ -19,18 +19,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/project-template-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/project-template-0.2.0
-hs-libraries: HSproject-template-0.2.0-0rTUlVHdAwN2uMITurt567
+hs-libraries: HSproject-template-0.2.0-6fptC5TJhHPGycOZmBa8sO
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
